import enum
class FeaturesType(enum.IntEnum):
    HISTORY=1
    HISTORY_ADVANCED=2
    STANDARD=3
    STANDARD_ADVANCED=4